@@ -1278,7 +1278,7 @@ class TestJobCommands(BaseTest):
     @patch('disco.task.TaskResult.write_files')
     def test_download_results(self, write_files_mock, makedirs_mock, is_dir_mock, path_exists_mock,
                               get_results_mock, is_logged_in_mock):
-        get_results_mock.return_value = [TaskResult('task_id', {'Iqoqo.stdout.log': 'some output'})]
+        get_results_mock.return_value = [TaskResult('task_id', {'Disco.stdout.log': 'some output'})]
         is_logged_in_mock.return_value = True
         runner = CliRunner()
         result = runner.invoke(cli, 'job download-results job_id -d destdir')
